;************************************************************
; 
; Correction of the monthly Clim by a factor X to take into
; account the under estimation of the seasonal cycle when
; the daily clim is computed from the monthly Clim.
; This is usefull for restoring experiment where monthly 
; restoring file is given to the model that will interpolate 
; it to daily values
;
;************************************************************

load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/gsn_code.ncl"
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/gsn_csm.ncl"
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/contributed.ncl"
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/shea_util.ncl"

begin

  varinClim  = "tos"
  indirClim  = "/esarchive/scratch/ptrascas/ninopacemaker/sst_anomalies/present/"
  infilClim  = "mon_tos_all_2y.nc"

  varinAnom  = "tos"
  indirAnom  = "/esarchive/scratch/ptrascas/ninopacemaker/sst_anomalies/present/"
  infilAnom  = "sstanomalies_012015-122016_orcagrid.nc"

  varo       = "thetao"
  Savdir     = "/esarchive/scratch/ptrascas/ninopacemaker/sst_anomalies/present/"
  Savfil_tmp = "tos_totalfield_present_nino1516_fullfield_inflatedseascycle_y"

  ; Offset is useful for not dividing by zero
  offset = 1000


;************************************************************
; No more input
;************************************************************
  xo = (/0,31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31/)

  fClim   = addfile(indirClim+infilClim, "r")
  fAnom   = addfile(indirAnom+infilAnom, "r")

  ; read the 24 timesteps inside totalfiled file 
  tmpClim = fClim->$varinClim$
  tmpAnom = fAnom->$varinAnom$

  tmp     = tmpClim
  tmp     = tmpClim + tmpAnom

  ; split the 24 months in to 2 different years
  dims   = dimsizes(tmp)
  nyea   = 2
  ntim   = dims(0)/2
  nlat   = dims(1)
  nlon   = dims(2)

  year   = new((/nyea,ntim,nlat,nlon/), typeof(tmp))
  year!0 = "year"
;  year!1 = tmp!0
;  year!2 = tmp!1
;  year!3 = tmp!2

  year(0,:,:,:) = tmp(0:11,:,:)
  year(1,:,:,:) = tmp(12::,:,:)
printVarSummary(year)

; ClmMon  = tmp
; ClmMon  = ClmMon*0.
  
  do y=0,nyea-1

    ClmMon_Ref = year(y,:,:,:)
    
;    printVarSummary(ClmMon_Ref)
;    printMinMax(ClmMon_Ref, True)
    
    ClmMon_Ref = ClmMon_Ref + offset
;************************************************************
; Interpolation of raw daily climatology
;************************************************************
    print("Compute daily Clim")

    ClmDay             = clmMon2clmDay(ClmMon_Ref, 0, 0)
    ClmDay!0           = "year_day"
    ClmDay&year_day    = ispan(1,365,1)
    ClmDay@information = "Raw daily average across all years"
    ClmDay@smoothing   = "None"
    
;    printVarSummary(ClmDay)
;    printMinMax(ClmDay, True)
    
    
;************************************************************
; loop 100 times to reduce error on 
;************************************************************
    print("Daily Clim correction")
    ClmMon = ClmMon_Ref
;    ClmMon = (/ClmMon_Ref/)
 
    kmax = 100
    do k=0,kmax-1
      kp = k+1
      print("iteration: "+kp+"/"+kmax)
      
    ;************************************************************
    ; Compute raw daily climatology
    ;************************************************************
;      print("Compute daily Clim")      
      ClmDay   = clmMon2clmDay(ClmMon, 0, 0)

    ;************************************************************
    ; Compute monthly clim
    ;************************************************************
;      print("Compute monthly clim from daily ...")
      ClmMon_Rec = ClmMon
      xi_d   = 0
      xi_f   = 0
      do i=0,dimsizes(xo)-2
        xi_d = xi_d + xo(i)
        xi_f = xi_d + xo(i+1) - 1    
        ClmMon_Rec(i,:,:) = dim_avg_n_Wrap(ClmDay(xi_d:xi_f,:,:), 0)
      end do

      Ratio      = ClmMon
      Ratio      = ClmMon_Ref/ClmMon_Rec 

;      printVarSummary(Ratio)
;      printMinMax(Ratio, True)

      ClmMon     = ClmMon*Ratio 

    end do
    Diff    = ClmMon-ClmMon_Ref
    printMinMax(Diff, True)
    ClmMon     = ClmMon - offset


;************************************************************
; Save Data
;************************************************************
    print("Save data")
    
    Savfil = Savfil_tmp+y+".nc"
    
    if (isfilepresent(Savdir+Savfil)) then
      system("/bin/rm -f "+Savdir+Savfil)
    end if
    system("csh -c 'if (! -d "+Savdir+") then ;  mkdir -p  "+Savdir+" ; chmod 775 "+Savdir+" ; endif'")
    fnc    = addfile (Savdir+Savfil, "c")   ; creation du nouveau fichier
    fnc->$varo$ = ClmMon
    
    fnc@creation_date  = systemfunc("date")          ; date de creation
    fnc@script_name    = systemfunc("pwd")+"/"+get_script_prefix_name()

  end do
end
